| Title: | Palettes for IDEM, IDDU, ACEFA, and The Kids |
|---|---|
| Description: | See: package title. |
| Authors: | Gerry Ryan [aut, cre] (ORCID: <https://orcid.org/0000-0003-0183-7630>) |
| Maintainer: | Gerry Ryan <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 2.0.0 |
| Built: | 2026-06-03 03:32:42 UTC |
| Source: | https://github.com/idem-lab/idpalette |
An alias for idpalette(p = "acefa", n, rev)
acefa(n = NULL, rev = FALSE)acefa(n = NULL, rev = FALSE)
n |
|
rev |
|
idpalette class object of hex colours length n.
The idpalette class has a print method that will plot the colours in the
object, but it is underneath that a character string of length n and can
be otherwise treated as such.
acefa(5)acefa(5)
An alias for idpalette(p = "iddu", n, rev)
iddu(n = NULL, rev = FALSE)iddu(n = NULL, rev = FALSE)
n |
|
rev |
|
idpalette class object of hex colours length n.
The idpalette class has a print method that will plot the colours in the
object, but it is underneath that a character string of length n and can
be otherwise treated as such.
iddu(5)iddu(5)
An alias for idpalette(p = "idem", n, rev)
idem(n = NULL, rev = FALSE)idem(n = NULL, rev = FALSE)
n |
|
rev |
|
character of length n
idpalette class object of hex colours length n.
The idpalette class has a print method that will plot the colours in the
object, but it is underneath that a character string of length n and can
be otherwise treated as such.
idem(7)idem(7)
Colour palettes for IDEM, IDDU, ACEFA, and The Kids
idpal( p = c("idem", "idem_official", "iddu", "iddu_official", "acefa", "acefa_official", "thekids", "thekids_official", "thekids_diverging") )idpal( p = c("idem", "idem_official", "iddu", "iddu_official", "acefa", "acefa_official", "thekids", "thekids_official", "thekids_diverging") )
p |
|
"idem", "iddu", and "acefa" return palettes for all colours in logos.
"..._official" palettes return only the four-colour palettes per the style-
guide from the designer.
"thekids" returns colours from the brand template, excluding black and
white. "_official" includes black and white, while "_diverging" includes
white, but excludes dark teal, midnight blue, and black, for use in
diverging colour schemes (duh)
NB: The additional IDEM, IDDU 'non-official' colours are estimated by a colour dropper thing Gerry found on the internet and may or may not be exactly correct.
character of hex values
idpal("idem")idpal("idem")
Create colour palettes based on IDEM, IDDU, ACEFA, and The Kids Research Institute Australia colours
idpalette(p, n = NULL, rev = FALSE)idpalette(p, n = NULL, rev = FALSE)
p |
|
n |
|
rev |
|
idpalette class object of hex colours length n.
The idpalette class has a print method that will plot the colours in the
object, but it is underneath that a character string of length n and can
be otherwise treated as such.
idpalette( "idem", n = 20, rev = TRUE ) kids_div <- idpalette( "thekids_diverging" ) kids_div str(kids_div) is.character(kids_div)idpalette( "idem", n = 20, rev = TRUE ) kids_div <- idpalette( "thekids_diverging" ) kids_div str(kids_div) is.character(kids_div)
Convenience wrapper to ggplot2::continuous_scale to allow use of
idpalette or any arbitrary set of colours to be used as a ggplot2 fill
or colour scale
scale_id_continuous( cols, aesthetics = c("fill", "colour"), na.value = "transparent", guide = "colourbar", ... )scale_id_continuous( cols, aesthetics = c("fill", "colour"), na.value = "transparent", guide = "colourbar", ... )
cols |
|
aesthetics |
Scale aesthetic. |
na.value |
Garn - whaddaya want in the |
guide |
A function used to create a guide or its name. See |
... |
Arguments passed on to |
A ggproto object of class Scale and ScaleContinuous
library(ggplot2) ggplot(mtcars) + geom_point( aes( x = disp, y = hp, colour = qsec ), size = 5 ) + scale_id_continuous( cols = iddu(), aesthetics = "colour" )library(ggplot2) ggplot(mtcars) + geom_point( aes( x = disp, y = hp, colour = qsec ), size = 5 ) + scale_id_continuous( cols = iddu(), aesthetics = "colour" )
An alias for idpalette(p = "thekids", n, rev)
thekids(n = NULL, rev = FALSE)thekids(n = NULL, rev = FALSE)
n |
|
rev |
|
idpalette class object of hex colours length n.
The idpalette class has a print method that will plot the colours in the
object, but it is underneath that a character string of length n and can
be otherwise treated as such.
thekids(8)thekids(8)